<?php

/**
 * @file
 * Views handler: Withdrawal operations.
 */

/**
 * Returns the available operations for withdrawal requests.
 */
class uc_funds_handler_field_withdrawal_operations extends views_handler_field {

  /**
   * Loads additional fields.
   */
  public function query() {
    $this->field_alias = 'operations';
  }

  /**
   * Alter rendering.
   */
  public function pre_render(&$values) {
    foreach ($values as $result) {
      $this->output = _ubercart_funds_withdrawal_operations($this, $result);
      $result->uc_funds_withdrawal_operations = $this->output;
    }
  }

  /**
   * Render the handler.
   */
  public function render($values) {
    $output = $values->uc_funds_withdrawal_operations;
    return $output;
  }

}

/**
 * Definition of _ubercart_funds_withdrawal_operations().
 */
function _ubercart_funds_withdrawal_operations($handler, $result) {
  $request_id = $result->request_id;
  $status = $result->uc_funds_withdrawal_requests_status;
  $current_display = $handler->view->current_display;
  $links = array();

  if (user_access('administer withdraw requests')) {
    if ($status == 'Pending approval') {
      $links['approve'] = array(
        'title' => 'Approve',
        'href' => 'admin/store/funds/withdrawals/approve/' . $request_id,
        'attributes' => array('class' => array('uc-funds-approve'), 'title' => 'Approve'),
      );
      $links['decline'] = array(
        'title' => 'Decline',
        'href' => 'admin/store/funds/withdrawals/decline/' . $request_id,
        'attributes' => array('class' => array('uc-funds-decline'), 'title' => 'Decline'),
      );
    }
    else {
      return t('None');
    }
  }

  $attributes = array('class' => 'uc-funds-links');

  return theme_links(array('links' => $links, 'attributes' => $attributes, 'heading' => array()));
}
